@@ -33,8 +33,4 @@ class << Gem::Specification
   end
 end
 
-begin
-  require_relative 'debian_ruby_standalone_config'
-rescue LoadError
-  # nothing
-end
+require_relative 'debian_ruby_standalone_config'
